==> fet_5.9.1.orig.tar.gz: fet-5.9.1/src/interface/addbuildingform.h <==
/***************************************************************************
                          addbuildingform.h  -  description
                             -------------------
    begin                : Feb 11, 2008
    copyright            : (C) 2008 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDBUILDINGFORM_H
#define ADDBUILDINGFORM_H

#include "addbuildingform_template.h"

#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

#include <qspinbox.h>
#include <qlineedit.h>
#include <q3textedit.h>


class AddBuildingForm : public AddBuildingForm_template {
public: 
	AddBuildingForm();
	~AddBuildingForm();

	void addBuilding();
};

#endif

==> fet_5.11.0.orig.tar.gz: fet-5.11.0/src/interface/addbuildingform.h <==
/***************************************************************************
                          addbuildingform.h  -  description
                             -------------------
    begin                : Feb 11, 2008
    copyright            : (C) 2008 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDBUILDINGFORM_H
#define ADDBUILDINGFORM_H

#include "ui_addbuildingform_template.h"

#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

#include <qspinbox.h>
#include <qlineedit.h>
#include <q3textedit.h>


class AddBuildingForm : public QDialog, Ui::AddBuildingForm_template {
	Q_OBJECT
public: 
	AddBuildingForm();
	~AddBuildingForm();

public slots:
	void addBuilding();
};

#endif
